@@ -134,6 +134,9 @@ class OflyService(Request):
 
         self.authorize_url = authorize_url
 
+        # wrap requests in a Requests session
+        self.session = requests.session()
+
     def _micro_to_milliseconds(self, microseconds):
         return microseconds / self.MICRO_MILLISECONDS_DELTA
 
@@ -212,15 +215,15 @@ class OflyService(Request):
                                            header_auth,
                                            **params)
 
-            response = requests.request(method,
-                                        url + '?' + params,
-                                        headers=headers)
+            response = self.session.request(method,
+                                            url + '?' + params,
+                                            headers=headers)
         else:
             params = self._sha1_sign_params(url, **params)
 
-            response = requests.request(method,
-                                        url + '?' + params,
-                                        data=data)
+            response = self.session.request(method,
+                                            url + '?' + params,
+                                            data=data)
 
         return Response(response)
 
@@ -277,6 +280,8 @@ class OAuth2Service(Request):
         if access_token is not None:
             self.access_token = access_token
 
+        self.session = requests.session()
+
     def get_authorize_url(self, response_type='code', **params):
         '''Returns a proper authorize URL.
 
@@ -307,13 +312,19 @@ class OAuth2Service(Request):
             # raise an error because credentials must be sent in this method
             raise ValueError('Either params or data dict missing.')
 
-        if key is not None:
-            grant_type = kwargs[key].get('grant_type', 'authorization_code')
+        grant_type = kwargs[key].get('grant_type', 'authorization_code')
+
+        # client_credentials flow uses basic authentication for a token
+        if grant_type == 'client_credentials':
+            kwargs['auth'] = (self.consumer_key, self.consumer_secret)
+        else:
             kwargs[key].update(client_id=self.consumer_key,
                                client_secret=self.consumer_secret,
                                grant_type=grant_type)
 
-        response = requests.request(method, self.access_token_url, **kwargs)
+        response = self.session.request(method,
+                                        self.access_token_url,
+                                        **kwargs)
 
         return Response(response)
 
@@ -325,7 +336,7 @@ class OAuth2Service(Request):
         :param url: The resource to be requested.
         :param \*\*kwargs: Optional arguments. Same as Requests.
         '''
-        response = requests.request(method, url, **kwargs)
+        response = self.session.request(method, url, **kwargs)
         return Response(response)
 
 
@@ -407,8 +418,12 @@ class OAuth1Service(Request):
                           **kwargs)
         return requests.session(hooks={'pre_request': hook})
 
-    def get_request_token(self, method='GET', **kwargs):
-        '''Gets a request token from the request token endpoint.
+    def get_raw_request_token(self, method='GET', **kwargs):
+        '''Gets a response from the request token endpoint.
+
+        Returns the entire parsed response, without trying to pull out the
+        token and secret.  Use this if your endpoint doesn't use the usual
+        names for 'oauth_token' and 'oauth_token_secret'.
 
         :param method: A string representation of the HTTP method to be used.
         :param \*\*kwargs: Optional arguments. Same as Requests.
@@ -426,7 +441,15 @@ class OAuth1Service(Request):
 
         response.raise_for_status()
 
-        data = parse_utf8_qsl(response.content)
+        return parse_utf8_qsl(response.content)
+
+    def get_request_token(self, method='GET', **kwargs):
+        '''Gets a request token from the request token endpoint.
+
+        :param method: A string representation of the HTTP method to be used.
+        :param \*\*kwargs: Optional arguments. Same as Requests.
+        '''
+        data = self.get_raw_request_token(method=method, **kwargs)
         return data['oauth_token'], data['oauth_token_secret']
 
     def get_authorize_url(self, request_token, **params):
